@@ -3,11 +3,16 @@
 # you use it directly and your code breaks horribly.
 package CGI::File::Temp;
 
-$CGI::File::Temp::VERSION = '4.26';
+$CGI::File::Temp::VERSION = '4.40';
 
 use parent File::Temp;
 use parent Fh;
 
+my $appease_cpants_kwalitee = q/
+use strict;
+use warnings;
+#/;
+
 use overload
     '""'  => \&asString,
     'cmp' => \&compare,
